@@ -39,71 +39,72 @@ static gboolean enable_debug = FALSE;
 void
 xfpm_debug (const char *func, const char *file, int line, const char *format, ...)
 {
-    va_list args;
-    
-    if ( !enable_debug )
-	return;
+  va_list args;
 
-    va_start (args, format);
+  if ( !enable_debug )
+    return;
 
-    fprintf (stdout, "TRACE[%s:%d] %s(): ", file, line, func);
-    vfprintf (stdout, format, args);
-    fprintf (stdout, "\n");
-    
-    va_end (args);
+  va_start (args, format);
 
+  fprintf (stdout, "TRACE[%s:%d] %s(): ", file, line, func);
+  vfprintf (stdout, format, args);
+  fprintf (stdout, "\n");
+
+  va_end (args);
 }
 
 void
 xfpm_warn (const char *func, const char *file, int line, const char *format, ...)
 {
-    va_list args;
+  va_list args;
 
-    if ( !enable_debug )
-	return;
+  if ( !enable_debug )
+    return;
 
-    va_start (args, format);
-    
-    fprintf(stdout, "TRACE[%s:%d] %s(): ", file, line, func);
-    fprintf (stdout, "***WARNING***: ");
-    vfprintf (stdout, format, args);
-    fprintf (stdout, "\n");
-    va_end (args);
+  va_start (args, format);
+
+  fprintf(stdout, "TRACE[%s:%d] %s(): ", file, line, func);
+  fprintf (stdout, "***WARNING***: ");
+  vfprintf (stdout, format, args);
+  fprintf (stdout, "\n");
+  va_end (args);
 }
 
-void xfpm_debug_enum (const gchar *func, const gchar *file, gint line,
-		      gint v_enum, GType type, const gchar *format, ...)
+void
+xfpm_debug_enum (const gchar *func, const gchar *file, gint line,
+                 gint v_enum, GType type, const gchar *format, ...)
 {
-    va_list args;
-    gchar *buffer;
-    
-    gchar *content = NULL;
-    GValue __value__ = { 0, };
-    
-    if ( !enable_debug )
-	return;
-    
-    g_value_init (&__value__, type);
-    g_value_set_enum (&__value__, v_enum);
-    
-    content = g_strdup_value_contents (&__value__);
-    
-    va_start (args, format);
-    g_vasprintf (&buffer, format, args);
-    va_end (args);
-	
-    fprintf(stdout, "TRACE[%s:%d] %s(): ", file, line, func);
-    fprintf(stdout, "%s: %s", buffer, content);
-    fprintf(stdout, "\n");
-    
-    g_value_unset (&__value__);	
-    g_free (content);
-    g_free (buffer);
+  va_list args;
+  gchar *buffer;
+
+  gchar *content = NULL;
+  GValue __value__ = { 0, };
+
+  if ( !enable_debug )
+    return;
+
+  g_value_init (&__value__, type);
+  g_value_set_enum (&__value__, v_enum);
+
+  content = g_strdup_value_contents (&__value__);
+
+  va_start (args, format);
+  g_vasprintf (&buffer, format, args);
+  va_end (args);
+
+  fprintf(stdout, "TRACE[%s:%d] %s(): ", file, line, func);
+  fprintf(stdout, "%s: %s", buffer, content);
+  fprintf(stdout, "\n");
+
+  g_value_unset (&__value__);
+  g_free (content);
+  g_free (buffer);
 }
 
 #endif /*defined(G_HAVE_ISO_VARARGS)*/
 
-void xfpm_debug_init (gboolean debug)
+void
+xfpm_debug_init (gboolean debug)
 {
     enable_debug = debug;
 }
