@@ -22,15 +22,12 @@
 #define __XFPM_DBUS_H
 
 #include <glib.h>
-#include <dbus/dbus.h>
-#include <dbus/dbus-glib.h>
+#include <gio/gio.h>
 
-gboolean	xfpm_dbus_name_has_owner 	   (DBusConnection *bus,
-						    const gchar *name);
-					  
-gboolean        xfpm_dbus_register_name  	   (DBusConnection *bus,
-						    const gchar *name);
-					  
-gboolean        xfpm_dbus_release_name   	   (DBusConnection *bus,
-						    const gchar *name);
+gboolean    xfpm_dbus_name_has_owner  (GDBusConnection *bus,
+                                       const gchar *name);
+gboolean    xfpm_dbus_register_name   (GDBusConnection *bus,
+                                       const gchar *name);
+gboolean    xfpm_dbus_release_name    (GDBusConnection *bus,
+                                       const gchar *name);
 #endif /* __XFPM_DBUS_H */
